@@ -15,6 +15,9 @@ export default function isReference (node: Node, parent: Node): boolean {
 			// disregard the `foo` in `class {foo(){}}` but keep it in `class {[foo](){}}`
 			case 'MethodDefinition': return parent.computed;
 
+			// disregard the `foo` in `class {foo=bar}` but keep it in `class {[foo]=bar}` and `class {bar=foo}`
+			case 'FieldDefinition' as any: return (parent as any).computed || node === (parent as any).value;
+
 			// disregard the `bar` in `{ bar: foo }`, but keep it in `{ [bar]: foo }`
 			case 'Property': return parent.computed || node === parent.value;
 
